:mod:`kotti.views.edit`
-----------------------

.. automodule:: kotti.views.edit
   :members:


.. toctree::
   :maxdepth: 3

   kotti.views.edit.actions
   kotti.views.edit.content
   kotti.views.edit.default_views
